==> predict3d_0.1.4.tgz: predict3d/NEWS.md <==
## predict3d version 0.1.4
==========================
(2022-Jan-20)

- compatible with rgl(>= 1.0.1)


## predict3d version 0.1.3.7
============================
(2020-Mar-27)

- can predict model with weights


## predict3d version 0.1.3.6
============================
(2020-Mar-27)

- bug-fixed 

## predict3d version 0.1.3.5
=========================
(2020-Mar-11)

- bug-fixed: ggPredict now can predict if the first predictor is not numeric


## predict3d version 0.1.3.4
============================
(2020-Mar-3)

- bug-fixed: can predict non-intercept model


## predict3d version 0.1.3.3
============================
(2019-Jun-7)

- CalEquation function can calculate intercept in multiple regression model with interaction

## predict3d version 0.1.3.2
============================
(2019-Apr-24)

- New arguments summarymode added to fit2newdata(), predict3d() and ggPredict()


## predict3d version 0.1.3.1
============================
(2019-Apr-11)

- New arguments xlab, ylab and zlab added to predict3d()

## predict3d version 0.1.3
===========================
(2019-Apr-3)

- New function gg_color_hue() and theme_bw2() added

## predict3d version 0.1.2
===========================
(2019-Mar-11)

- Bug-fixed

- New function restoreData2(), restoreData3()  added


## predict3d version 0.1.1
===========================
(2019-Mar-9)

- Bug-fixed

- New function add_lines() added



## predict3d version 0.1.0
===========================
(2019-Mar-6)

- New function ggPredict() and predict3d() added

- New function fit2newdata() added

==> predict3d_0.1.6.tgz: predict3d/NEWS.md <==
## predict3d version 0.1.6
==========================
(2025-Oct-1)

- compatible with ggplot2(>= 4.0.0)


## predict3d version 0.1.5
==========================
(2024-Apr-5)

- independent of package prediction


## predict3d version 0.1.4
==========================
(2022-Jan-20)

- compatible with rgl(>= 1.0.1)


## predict3d version 0.1.3.7
============================
(2020-Mar-27)

- can predict model with weights


## predict3d version 0.1.3.6
============================
(2020-Mar-27)

- bug-fixed 

## predict3d version 0.1.3.5
=========================
(2020-Mar-11)

- bug-fixed: ggPredict now can predict if the first predictor is not numeric


## predict3d version 0.1.3.4
============================
(2020-Mar-3)

- bug-fixed: can predict non-intercept model


## predict3d version 0.1.3.3
============================
(2019-Jun-7)

- CalEquation function can calculate intercept in multiple regression model with interaction

## predict3d version 0.1.3.2
============================
(2019-Apr-24)

- New arguments summarymode added to fit2newdata(), predict3d() and ggPredict()


## predict3d version 0.1.3.1
============================
(2019-Apr-11)

- New arguments xlab, ylab and zlab added to predict3d()

## predict3d version 0.1.3
===========================
(2019-Apr-3)

- New function gg_color_hue() and theme_bw2() added

## predict3d version 0.1.2
===========================
(2019-Mar-11)

- Bug-fixed

- New function restoreData2(), restoreData3()  added


## predict3d version 0.1.1
===========================
(2019-Mar-9)

- Bug-fixed

- New function add_lines() added



## predict3d version 0.1.0
===========================
(2019-Mar-6)

- New function ggPredict() and predict3d() added

- New function fit2newdata() added
